# 共立出版様用汎用クラスファイル

#### 付属のファイル
* kbdbook.cls （クラスファイル）
* mythm.sty（定理や証明などの設定の雛形）
* index.ist（索引用スタイルファイル）
* main.tex（見本用ファイルのコンパイル用元締めファイル）
* 見本用ファイル（sample/以下のファイル）

## 使用に関して
### 執筆TeX環境について
それ以前のものでも動作はしますが，texlive2016以降を推奨です．

### コンパイルや処理ファイルの構成
本クラスファイルはplatex, uplatexでのみ使用できます．
LuaLaTeX，XeLaTeXなどには対応しておりません．

下記はプリアンブル，元締めファイルとしての基本的な構成例です．
必要に応じてパッケージなどを追加してください．

コメントアウトされている項目については後述します．

```
\documentclass[a5/13Q,%% or b5/13Q or 4x6/13Q
dvipdfmx,
uplatex,% platexを使う場合は指定しない
%useotf,% otfパッケージを使う場合
]{kbdbook}
% \usepackage[scale=1]{otf}
\usepackage{graphicx}
\usepackage[T1]{fontenc}
\usepackage{amsmath,amssymb}
\usepackage{bm}
\usepackage{makeidx}
\usepackage{enumitem}
\makeindex
% \usepackage{author_macro}

\includeonly{%%
 preface,
 chap01,
 chap02,
 chap03,
 chap04,
 chap05,
 appendixA,
 appendixB
}

\begin{document}
\frontmatter%% 前付の指定
\include{preface}
\tableofcontents
\mainmatter
\include{chap01}
\include{chap02}
\include{chap03}
\include{chap04}
\include{chap05}
\appendix
\include{appndixA}
\include{appndixB}
\backmatter
\bibliography{xxxx} % xxxx.bib
\bibliographystyle{xxxx} %xxxx.bst
\printindex
\end{document}

```

### クラスファイルについて

本文で用いるコマンド，環境はjbook.clsに準拠になります．
使い方はjbook.clsの仕様に合わせています．

> ※ 出力はPDFが前提です，昨今の(u)platexでのPDF出力はdvipdfmxを経由させることが
> 事実上標準です．よってクラスオプション指定で`dvipdfmx`は必須になります．


#### 基本的なクラスオプション
##### 判形指定
いずれも本文サイズ（\normalsize）は13Qです．
* A5判の場合
```
\documentclass[a5/13Q,dvipdfmx]{kbdbook}
```
* B5判の場合
```
\documentclass[b5/13Q,dvipdfmx]{kbdbook}
```
* 4x6判の場合
```
\documentclass[4x6/13Q,dvipdfmx]{kbdbook}
```
##### 使用するtexエンジン
本クラスファイルはplatex, uplatexで動作します．
デフォルトはplatexでuplatexを使いたい場合はクラスオプションに`uplatex`を追記します．
```
\documentclass[a5/13Q,dvipdfmx,uplatex]{kbdbook}
```
> オプション扱いにはしていますが，特に理由がなければuplatexのご使用を推奨します．

##### otf パッケージを使う場合
```
\documentclass[a5/13Q,dvipdfmx,uplatex,useotf]{kbdbook}
\usepackage[scale=1]{otf}
```
otfパッケージを使う場合はオプションに`useotf` を指定してください．  
（因みにこれを指定せずにotfパッケージを読むと
`When you'd like to use "otf package", I have to designate a "useotf" class option.`
というエラーメッセージと共に処理が止まります．）

また和文サイズの補正するため `scale=1` を指定してください．

そのほかのクラスオプションはjbookと同様です．

#### 索引  
見出しなどを付ける索引用のスタイルファイルとしてindex.istを付属させています．
```
upmendex -s index.ist main.idx
```
のように `-s` 指定で読ませてください．

#### クラスファイルで読まれるパッケージ
本クラスファイルでは以下のパッケージを読み込みます．
詳細は一番最後に記します．
* plautopatch
* lmodern
* helvet
* multirow
* array

#### 文書ファイルの構成について
処理対象のファイルは`\documentclass`が記された元締めファイル（main.texなど）を作成し，
章ごとにファイルを分割して`\include`で読み込む形で執筆されることを推奨します．
`\includeonly`コマンドは`\include`で指定された各ファイルの読み込みを制御します．
これによりコンパイル時間が短縮でき，ページ番号，章番号，章を跨いだ
相互参照などの情報は確保された状態で効率的にプレビューができます．

このような部分コンパイルを行なう場合 **あらかじめ全体を処理** したのち，
不要な章をコメントアウトして，必要な章のみをアクティブにします．

* 全体を処理する場合  
（各ファイルは`,`で区切ります）
```
\includeonly{%%
 preface,% まえがき
 chap01, %1章
 chap02, %2章
 chap03, %3章
 chap04, %4章
 chap05, %5章
}
```
* 2章のみ処理したい場合  
```
\includeonly{%%
% preface,% まえがき
% chap01, %1章
 chap02, %2章
% chap03, %3章
% chap04, %4章
% chap05, %5章
}
```

### クラスファイルで読まれるパッケージの解説

前述したように本クラスファイルはあらかじめいくつかのパッケージを読み込みます．

* plautopatch.sty  
ここ最近のtexliveに納められている比較的使用頻度の高いパッケージのうち(u)pllatexと相性に
問題のある一部のパッケージで起こる不具合を自動的にフォローしてくれる（不具合解消のpatchを自動的に読む）パッケージです．
コンパイル時にplautopatch.styが存在した場合は無条件に読まれるようにしています．

* lmodern.sty  
latexの欧文フォントをアウトライン形式で中間サイズで使えるようにできるようになります．
T1というエンコーディングに対応してます．

* helvet.sty  
\sffamily をHelveticaに変更します．

* array.sty  
tabular環境やarray環境の機能を拡張します．
（plautopatchパッケージが存在すれば，plarrayパッケージが追加で読み込まれます）

またデフォルトでは読ませていませんが，文書の主旨，執筆の方針によっては便利なものを挙げます．

* enumitem .sty
enumitem packageは箇条書き（enumerate, itemize. description）の体裁の変更やラベルの指定を
柔軟に行えるパッケージ．箇条書きの体裁など部分的に変更させたい場合や，デフォルトの体裁を変更させたい場合など読ませておくとなにかと便利です．

<https://konoyonohana.blog.fc2.com/blog-entry-58.html>

で使い方が解説されています．   
より詳細な解説は
```
texdoc enumitem
```
でマニュアルが読めます．
* mathtools  
amsmathによる数式を拡張するpackageで，amsmathでは面倒だった数式の配置など細かい指定が出来るようになります．

<https://qiita.com/Yarakashi_Kikohshi/items/6362bf26828bfcfdb289>

<http://xyoshiki.web.fc2.com/tex/mathtools.html>

これも`texdoc mathtools`で詳細なマニュアルが読めます．

## 独自コマンドの扱いについて
執筆に必要な独自コマンドを定義して使用される場合は
`\newcommand`，あるいは`\renewcommand`を使用し，
別ファイルのauthor_macro.styとしてまとめて，`\usepackage{author_macro}`で読ませてください．
読ませる順番はもっとも最後の`\usepackage`としてください．
（なおauthour_macro.sty内では`\makeatletter`や`\makeatother`の指定は不要です．）

### hyperref パッケージについて
hyperrefパッケージは既存のLaTeXマクロのあちこちを書き直しを行います．
本クラスファイルはhyperrefパッケージに対しての動作は保証できません．
ご使用にならないようお願いします．

## 入稿について
### 本文のLaTeXでの記述  
jbook.clsに準拠して記述してください．
プリアンブルなどの指定は後述する例をご覧ください．
### 入稿データ  
入稿の際は文書全体を処理したPDFとコンパイルでエラーがない状態のTeX原稿ファイル，
画像ファイルは，graphicxパッケージを用い，PDF形式（EPSは受け付けますがPDFが望ましい）を用いてください．
  
入稿は以下のファイルを揃えてください．
* texの原稿ファイル
* クラスファイル類（このアーカイブに含まれるクラスファイル，パッケージ）
* 使用する画像ファイル
* 処理後に生成されるlogファイル（入稿後のデータ検証に必要）
* 独自定義をまとめたauthor_macro.sty（後述します）

### 参考文献について
参考文献につきましては，bibtexで生成したもの，あるいは直接記述したものでも結構です．
bibtexを用いた場合は文献の再構築を行う場合もありますので，
**bibファイル** ，用いた **bstファイル** も一緒にご入稿ください．

### 「定理」「定義」「証明」などについて
`\newthorem`を用いて定義をするようにしてください．
amsthmパッケージをつかった雛形をmythm.styとしてまとめてあります．
実際の簡単な使用例をthm_sample.texに記していますので参考にしてください．
問題なければ，そのままお使いください．

### 相互参照について
図や表，式番号などは可能な限り，`\label`，`\ref`での相互参照をお使いください．

* 共著の場合  
その際のラベル名が他章と重複すると正しい参照が行われなくなります．
それぞれに固有のラベル名を指定してください．
例として執筆者のご自身のイニシャル，章番号や章タイトルなどを付加するなどする方針があります．

 たとえば，（イニシャルYDの方の場合）
```
\section{..}\label{sec:1}→\label{YD:sec:1}
```


